@@ -20,7 +20,7 @@ class CommunityPermissions(LDPPermissions):
         return obj.community
 
     def get_object_permissions(self, request, view, obj):
-        from djangoldp_community.models import Community, CommunityMember
+        from djangoldp_community.models import Community, CommunityMember, CommunityProfile, CommunityAddress
 
         perms = set(super().get_object_permissions(request, view, obj))
         allow_continue = True
@@ -29,7 +29,7 @@ class CommunityPermissions(LDPPermissions):
                 allow_continue = False
         elif hasattr(obj, 'circle'):
             if not obj.circle.members.filter(user=request.user).exists() or obj.circle.status != "Public":
-                    allow_continue = False
+                allow_continue = False
 
         if allow_continue:
             perms = perms.union({'view'})
@@ -38,7 +38,8 @@ class CommunityPermissions(LDPPermissions):
 
             if is_authenticated_user(request.user) and community.members.filter(user=request.user).exists():
                 # Any member can add a job offer, circle or project to the community
-                if not isinstance(obj, Community) and not isinstance(obj, CommunityMember):
+                if not isinstance(obj, Community) and not isinstance(obj, CommunityMember) and\
+                   not isinstance(obj, CommunityProfile) and not isinstance(obj, CommunityAddress):
                     perms = perms.union({'add'})
 
                 member = community.members.get(user=request.user)
@@ -52,7 +53,7 @@ class CommunityPermissions(LDPPermissions):
                             # Admins can't delete community or other admins, but have super-powers on everything else
                             # I can't delete myself if I am the last member
                             perms = perms.union({'delete'})
-                    elif not isinstance(obj, Community):
+                    elif not isinstance(obj, Community) and not isinstance(obj, CommunityProfile):
                         perms = perms.union({'delete'})
                 elif isinstance(obj, CommunityMember) and obj.user == request.user:
                     perms = perms.union({'delete'})
@@ -72,9 +73,10 @@ class CommunityCirclePermissions(CirclePermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            community = Community.objects.get(slug=resolved.kwargs['slug'])
-            if community.members.filter(user=request.user).exists():
-                perms = perms.union({'add'})
+            if hasattr(resolved.kwargs, 'slug'):
+                community = Community.objects.get(slug=resolved.kwargs['slug'])
+                if community.members.filter(user=request.user).exists():
+                    perms = perms.union({'add'})
         return perms
 
 
@@ -90,9 +92,10 @@ class CommunityProjectPermissions(ProjectPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            community = Community.objects.get(slug=resolved.kwargs['slug'])
-            if community.members.filter(user=request.user).exists():
-                perms = perms.union({'add'})
+            if hasattr(resolved.kwargs, 'slug'):
+                community = Community.objects.get(slug=resolved.kwargs['slug'])
+                if community.members.filter(user=request.user).exists():
+                    perms = perms.union({'add'})
         else:
             return self.get_object_permissions(request, view, obj)
         return perms
@@ -110,9 +113,10 @@ class CommunityJobPermissions(LDPPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            community = Community.objects.get(slug=resolved.kwargs['slug'])
-            if community.members.filter(user=request.user).exists():
-                perms = perms.union({'add'})
+            if hasattr(resolved.kwargs, 'slug'):
+                community = Community.objects.get(slug=resolved.kwargs['slug'])
+                if community.members.filter(user=request.user).exists():
+                    perms = perms.union({'add'})
         else:
             return self.get_object_permissions(request, view, obj)
         return perms
@@ -126,10 +130,30 @@ class CommunityMembersPermissions(CommunityPermissions):
         if obj is None:
             from djangoldp_community.models import Community
             resolved = resolve(request.path_info)
-            community = Community.objects.get(slug=resolved.kwargs['slug'])
-            if community.members.filter(user=request.user).exists():
-                if community.members.get(user=request.user).is_admin:
+            if hasattr(resolved.kwargs, 'slug'):
+                community = Community.objects.get(slug=resolved.kwargs['slug'])
+                if community.members.filter(user=request.user).exists():
+                    if community.members.get(user=request.user).is_admin:
+                        perms = perms.union({'add'})
+                if community.allow_self_registration:
                     perms = perms.union({'add'})
         else:
             return self.get_object_permissions(request, view, obj)
         return perms
+
+class CommunityProfilePermissions(CommunityPermissions):
+    filter_backends = []
+
+    def get_container_permissions(self, request, view, obj=None):
+        perms = set({'view'})
+        if obj is None:
+            from djangoldp_community.models import Community
+            resolved = resolve(request.path_info)
+            if hasattr(resolved.kwargs, 'slug'):
+                community = Community.objects.get(slug=resolved.kwargs['slug'])
+                if community.members.filter(user=request.user).exists():
+                    if community.members.get(user=request.user).is_admin:
+                        perms = perms.union({'add', 'change'})
+        else:
+            return self.get_object_permissions(request, view, obj)
+        return perms
\ No newline at end of file
